Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(93)

Unified Diff: lib/compiler/implementation/lib/coreimpl_patch.dart

Issue 10887024: Move print to corelib. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address review comment. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/compiler/implementation/lib/coreimpl.dart ('k') | runtime/bin/builtin.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/compiler/implementation/lib/coreimpl_patch.dart
diff --git a/lib/compiler/implementation/lib/coreimpl_patch.dart b/lib/compiler/implementation/lib/coreimpl_patch.dart
index 3d2a235d00e9379085d02ae70a9531d94ab2b17f..ed5c547228d5068ba97cc26647182832536e404c 100644
--- a/lib/compiler/implementation/lib/coreimpl_patch.dart
+++ b/lib/compiler/implementation/lib/coreimpl_patch.dart
@@ -2,9 +2,21 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Patch file for dart:core classes.
+// Patch file for dart:coreimpl classes.
-// Path for Object implementation.
+// Patch for 'print' function.
+patch class PrintImplementation {
+ patch static void print(var obj) {
+ if (obj is String) {
+ Primitives.printString(obj);
+ } else {
+ Primitives.printString(obj.toString());
+ }
+ }
+}
+
+
+// Patch for Object implementation.
// TODO(ager): Split out into object_patch.dart and allow #source
// in patch files?
patch class ObjectImplementation {
« no previous file with comments | « lib/compiler/implementation/lib/coreimpl.dart ('k') | runtime/bin/builtin.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698